/* orckit_quirks.c ...... fix quirks in orckit adsl modems
 *                        mulix <mulix@actcom.co.il>
 *
 * $Id: orckit_quirks.c,v 1.3 2002/03/01 01:23:36 quozl Exp $
 */

#include <string.h>
#include <sys/types.h>
#include <sys/select.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include "pptp_msg.h"
#include "pptp_options.h"
#include "pptp_ctrl.h"
#include "util.h"



/* return 0 on success, non zero otherwise */
int
orckit_atur3_build_hook(struct pptp_out_call_rqst* packet)
{
    unsigned int name_length = 10;

    struct pptp_out_call_rqst fixed_packet = {
        {0}, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        {'R','E','L','A','Y','_','P','P','P','1',0}, {0} };
	SET_PPTP_HEADER_CTRL(fixed_packet.header, PPTP_OUT_CALL_RQST);
	//fixed_packet.call_id = hton16(call->callid);
	//fixed_packet.call_sernum = hton16(call->sernum);
	fixed_packet.bps_min = hton32(PPTP_BPS_MIN);
    fixed_packet.bps_max = hton32(PPTP_BPS_MAX);
	fixed_packet.bearer = hton32(PPTP_BEARER_DIGITAL);
    fixed_packet.framing = hton32(PPTP_FRAME_ANY);
	fixed_packet.recv_size = hton16(PPTP_WINDOW);
    fixed_packet.phone_len = hton16(name_length);
    
    if (!packet)
	return -1;

    memcpy(packet, &fixed_packet, sizeof(*packet));

    return 0;
}

/* return 0 on success, non zero otherwise */
int
orckit_atur3_set_link_hook(struct pptp_set_link_info* packet,
			   int peer_call_id)
{
    struct pptp_set_link_info fixed_packet = { 
        {0}, 0, 0, 0xffffffff, 0xffffffff }; 
	SET_PPTP_HEADER_CTRL(fixed_packet.header, PPTP_SET_LINK_INFO);
	fixed_packet.call_id_peer = hton16(peer_call_id);

    if (!packet)
	return -1;

    memcpy(packet, &fixed_packet, sizeof(*packet));
    return 0;
}

/* return 0 on success, non 0 otherwise */
int
orckit_atur3_start_ctrl_conn_hook(struct pptp_start_ctrl_conn* packet)
{
    struct pptp_start_ctrl_conn fixed_packet = {
	{0}, 0, 0, 0, 0, 0, 0, 0,
	{'R','E','L','A','Y','_','P','P','P','1',0}, 
	{'M','S',' ','W','i','n',' ','N','T',0} };
    /* we'll set the header later */
    fixed_packet.version = hton16(PPTP_VERSION);
    fixed_packet.framing_cap = hton32(PPTP_FRAME_ASYNC);
    fixed_packet.bearer_cap = hton32(PPTP_BEARER_ANALOG);
    fixed_packet.max_channels = hton16(0); /* max channels */
    fixed_packet.firmware_rev = hton16(0x6021);

    if (!packet)
	return -1;

    /* grab the header from the original packet, since we dont
       know if this is a request or a reply */
    memcpy(&fixed_packet.header, &packet->header, sizeof(struct pptp_header));

    /* and now overwrite the full packet, effectively preserving the header */
    memcpy(packet, &fixed_packet, sizeof(*packet));
    return 0;
}


